@@ -5,6 +5,7 @@ from .bernstein import Bernstein
 from .clock import Clock, GlobalClock
 from .crypt import Crypt
 from .dataframe_tools import slugify
+from .distributions import DistFitter
 from .ecdf import ecdf
 from .fit import Fitter
 from .gsheet import GSheet
@@ -12,6 +13,7 @@ from .hvtools import cc, hist, Animator, beta_plots
 from .item import Item
 from .iterify import iterify
 from .memory import mem_show, mem_get
+from .parallel import Parallel
 from .param_state import ParamState
 from .plotting import figure, get_cc
 from .postgres import PG
@@ -21,6 +23,11 @@ from .shaper import Shaper
 from .timer import Timer
 import easier.hvtools as hv  # Need this weird import to make hv symbol work 
 import easier.filtering as filtering
+from .nice_dates import nice_dates
+from .duck import Duck
+
+# Alias for nice_dates
+date_formatter = nice_dates
 
 from .outlier_tools import (
     kill_outliers_iqr,
@@ -37,6 +44,8 @@ from .utils import (
     print_error,
     django_reconnect,
     screen_width_full,
+    BlobMixin,
+    BlobAttr,
 )
 
 # alias for ease of remembering the name
